pub enum Structure<'a> {
    Struct {
        struct_name: &'a Ident,
        struct_attrs: &'a Vec<Attribute>,
    },
    EnumVariant {
        enum_name: &'a Ident,
        enum_attrs: &'a Vec<Attribute>,
        variant_name: &'a Ident,
        variant_attrs: &'a Vec<Attribute>,
    },
}
The data type the field is under

Variants



Struct

Fields

struct_name: &'a Ident
struct_attrs: &'a Vec<Attribute>


EnumVariant

Fields

enum_name: &'a Ident
enum_attrs: &'a Vec<Attribute>
variant_name: &'a Ident
variant_attrs: &'a Vec<Attribute>

Implementations

Returns attributes on the declaration of the fields AND if a enum on the enum item

Returns attributes on the declaration of the fields

Struct name or just the variant

Struct name or enum and variant name concatenated with double colon